/* -------------------------------------------------------
                        digit4_demo.c

     Testprogramm fuer 4 stelliges 7-Segmentmodul (China)
     mit 74HC595 Schieberegistern

     Anmerkung : leider muessen die Anzeigesegmente des
                Moduls gemultiplext werden, da nur
                2 Schieberegister enthalten sind.
                SR sind kaskadiert, zuerst ist der
                Datenwert der Ziffer, danach die
                Multiplexstelle hinauszuschieben.

     Hardware  : Chinamodul "4-Bit LED Digital Tube Modul"

     IDE       : keine (Editor / make)
     Toolchain : SDCC 3.6

     MCU   :  AT89S52
     XTAL  :  12 MHz (core 1 MHz)

     21.01.2018  R. Seelig
   ------------------------------------------------------ */

/*
   Anschluesse:
 ------------------------------------------------------
   Pinbelegung:

   4 Bit LED Digital Tube Module                  MCS-51
   -------------------------------------------------------

       (shift-clock)   Sclk   -------------------- P1_0
       (strobe-clock)  Rclk   -------------------- P1_1
       (ser. data in)  Dio    -------------------- P1_2
       (+Ub)           Vcc
                       Gnd



   Anzeigenposition 0 ist das rechte Segment des Moduls

            +-----------------------------+
            |  POS3   POS2   POS1   POS0  |
    Vcc  o--|   --     --     --     --   |
    Sclk o--|  |  |   |  |   |  |   |  |  |
    Rclk o--|  |  |   |  |   |  |   |  |  |
    Dio  o--|   -- o   -- o   -- o   -- o |
    GND  o--|                             |
            |   4-Bit LED Digital Tube    |
            +-----------------------------+

   Segmentbelegung der Anzeige:

       a
      ---
   f | g | b            Segment | dp |  g  |  f  |  e  |  d  |  c  |  b  |  a  |
      ---               --------------------------------------------------------
   e |   | c            Bit-Nr. |  7 |  6  |  5  |  4  |  3  |  2  |  1  |  0  |
      ---
       d

   Segmente leuchten bei einer logischen 0 (gemeinsame Kathode) !!!

*/

#include <stdint.h>

#include "8052.h"
#include "delay.h"

#include "seg7anz_v2.h"


#define d4char_C    0xc6       // Bitmuster fuer grosses C
#define d4char_oo   0x9c       // Bitmuster fuer hochgestelltes o

/* ---------------------------------------------------------------------------------
                                      M-A-I-N
   ---------------------------------------------------------------------------------*/

int main(void)
{
  uint16_t   oldsek = 1;
  uint16_t   counter = 0;

  digit4_init();                        // Modul initialisieren

  digit4_setdez(1234);
  delay(1000);

 // Bsp. Anzeige von 15 Grad Celcius
  digit4_setdez8bit(15,2);
  seg7_4digit[1]= d4char_oo;
  seg7_4digit[0]= d4char_C;

  delay(1000);

  digit4_setdp(2);                      // Kommapunkt anzeigen

  sek= 50;
  // endlose Zaehlschleife
  while(1)
  {
    if (oldsek != sek)
    {
      oldsek= sek;
      digit4_setdez8bit(min,2);
      digit4_setdez8bit(sek,0);
    }
  }
}
