/* -------------------------------------------------------
                        seg7anz_v2.h

     Headerdatei fuer 4 stelliges 7-Segmentmodul (China)
     mit 74HC595 Schieberegistern

     Anmerkung: leider muessen die Anzeigesegmente des
                Moduls gemultiplext werden, da nur
                2 Schieberegister enthalten sind.
                SR sind kaskadiert, zuerst ist der
                Datenwert der Ziffer, danach die
                Multiplexstelle hinauszuschieben.

     Hardware : Chinamodul "4-Bit LED Digital Tube Modul"

     Bemerkung: Damit die Anzeige gemultiplext werden
                kann, wird Timer2 als interruptbe-
                triebener Taktgeber eingesetzt.

                Zusaetzlich wird ist mit diesem Timer ein
                Softwareuhrwerk implementiert


     MCU       : at89s52
     XTAL      : 12 MHz ( 1 MHz core )

     21.01.2018  R. Seelig
   ------------------------------------------------------ */

/*
   Anschluesse:
 ------------------------------------------------------
   Pinbelegung:

   4 Bit LED Digital Tube Module                  MCS-51
   -------------------------------------------------------

       (shift-clock)   Sclk   -------------------- P1_0
       (strobe-clock)  Rclk   -------------------- P1_1
       (ser. data in)  Dio    -------------------- P1_2
       (+Ub)           Vcc
                       Gnd


   Anzeigenposition 0 ist das rechte Segment des Moduls

            +-----------------------------+
            |  POS3   POS2   POS1   POS0  |
    Vcc  o--|   --     --     --     --   |
    Sclk o--|  |  |   |  |   |  |   |  |  |
    Rclk o--|  |  |   |  |   |  |   |  |  |
    Dio  o--|   -- o   -- o   -- o   -- o |
    GND  o--|                             |
            |   4-Bit LED Digital Tube    |
            +-----------------------------+

   Segmentbelegung der Anzeige:

       a
      ---
   f | g | b            Segment | dp |  g  |  f  |  e  |  d  |  c  |  b  |  a  |
      ---               --------------------------------------------------------
   e |   | c            Bit-Nr. |  7 |  6  |  5  |  4  |  3  |  2  |  1  |  0  |
      ---
       d

   Segmente leuchten bei einer logischen 0 (gemeinsame Kathode) !!!

*/

#ifndef in_seg7anz_v2
  #define in_seg7anz_v2

  #include <stdint.h>

  #include "8052.h"
  #include "mcs_gpio.h"


  //  Anschlusspins des Moduls
  #define srdata_set()        P1_2_set()
  #define srdata_clr()        P1_2_clr()

  #define srstrobe_set()      P1_1_set()
  #define srstrobe_clr()      P1_1_clr()

  #define srclock_set()       P1_0_set()
  #define srclock_clr()       P1_0_clr()


  extern uint8_t  seg7_4digit[4];
  extern uint8_t  led7sbmp[16];

  // ----------------------------------------------------
  //   globale Variable des Uhrwerks
  // ----------------------------------------------------

  extern volatile uint8_t ms50tick;
  extern volatile uint8_t halfsek;
  extern volatile uint8_t sek;
  extern volatile uint8_t min;
  extern volatile uint8_t std;


  /* ----------------------------------------------------------
     Prototypen
     ---------------------------------------------------------- */

  void digit4_delay(void);
  void digit4_ckpuls(void);
  void digit4_stpuls(void);
  void digit4_outbyte(uint8_t value);
  void digit4_setdez(int value);
  void digit4_setdez8bit(uint8_t value, uint8_t pos);
  void digit4_sethex(uint16_t value);
  void digit4_setall(uint8_t c3, uint8_t c2, uint8_t c1, uint8_t c0);
  void digit4_setdp(char pos);
  void digit4_clrdp(char pos);
  void digit4_init(void);

  void tim2_init(void);
  void tim2_interrupt(void) __interrupt(5);

#endif
